# Summer Undergraduate Research: Machine Learning for Gravitational Waves!

## Greetings

First of all, welcome Simran to our group! This is the Max Planck Institute for Gravitationalphysics (Also called AEI, Albert Einstein Institute). The AEI in Hannover carries on a variety of experimental, theoretical and numerical research topics on gravitational waves. People here develop and operate a ground-based gravitational wave detector GEO-600, look for and analyze the signals of gravitational waves from compact binary coalescence (CBC) and continuous waves (CW), and so on. A more detailed introduction of this institute can be found [here](https://www.aei.mpg.de). 

The mentor would be me, Yifan Wang, my personal website is [here](https://yi-fan-wang.github.io). 

## Brief Introduction on the research project

Gravitational wave astronomy has brought observational astronomy into a new era. So far over 50 gravitaitonal-wave events have been recorded by [LIGO](https://www.ligo.org) (Laser Interferometer Gravitational-wave Observatory) and [Virgo](https://www.virgo-gw.eu) detectors, all are from mergers of black holes or neutron stars. The discover has lead to significant scientific progress, e.g, testing the validity of general relativity in strong gravity regime, inferring the population synthesis of black holes and neutron stars, and so on.

A classcial method to identify gravitational-wave signals from CBC in the data segment is match filtering. Since it is in priori unknown what kinds of gravitaional waves from which masses of black holes exist in the data, people just build a huge number of precomputed waveforms covering different masses and spins of black holes as much as possible, and then correlate the waveforms with data to produce the signal-to-noise ratio (SNR). If the SNR exceeds a certain threshold, it's a hint for signals. Using time sliding techniques between two detectors, the SNR distribution for background noise can also be produced. The p-value of a signal candidate with respect to the background noise represents how rare this kind of signal can happen, or in another words, the false alarm rate. The first gravitaional-wave event, GW150914, was identified with a very significant false alarm rate, lower than one false alarm every 203000 years.   

In recent few years, a new technique based on machine learning / deep learning is looking for alternative way to search for and analyze gravitational waves. Some results are remarkable, for example, the classcial match filtering technique can be very computational expensive (takes 10k cpus to run weeks), while the machine learning methods take much less computation time becuase it can better capture the intrinsic pattern of data. This new emerging field is promising, however, since this is a young field there's still plenty of scope for improvement. Can machine learning perform better than classcial match filtering ? In what situation it performs better, and in which it's worse? What is the best structure for designing a deep learning network, and why? Questions like these are interesting and waiting for us to explore !

The aim of this undergraduate project is to reproduce and improve the results of some journal literature using machine learning techniques to identify gravitational wave signals from noisy data. Depending on the progress, the student can perform some further exploration after reproducing the results, for example, searching for real data from the LIGO and Virgo, computing the false alarm rate for a machine learning approach for searching for gravitational wave. This project will take ~3 months, the student should write a brief report at the end. Some prerequisite knowledge on general relativity, gravitational waves, python programming and machine learning would be helpful.

## Research Goals: 

- [ ] Reproduce the results of this [paper](https://arxiv.org/abs/2011.04418). The git repository associated with this paper is [here](https://github.com/yi-fan-wang/improved-gwcnn). 
- [ ] Using the above CNN (convolutional neural network) to search for LIGO and Virgo real data. We have searched for the real data using classcial method in this [paper](https://arxiv.org/abs/2105.09151). I really look forward to seeing the performance of machine learning.

Even furthere goals:
- [ ] Reproduce the results of a machine learning paper to find gravitational wave events, e.g. 
    - https://arxiv.org/abs/1909.13442 Gravitational wave signal recognition of O1 data by deep learning, He Want et al.
    - https://journals.aps.org/prl/abstract/10.1103/PhysRevLett.120.141103 Matching Matched Filtering with Deep Networks for Gravitational-Wave Astronomy
    - https://arxiv.org/abs/1909.06296 Bayesian parameter estimation using conditional variational autoencoders for gravitational-wave astronomy
- [ ] compute the p value/ false alarm rate for machine learning algorithm 
- [ ] extend the above paper to LIGO and Virgo real data

## Roadmap:

See [wiki](https://gitlab.aei.uni-hannover.de/yifan.wang/summer-machinelearning/-/wikis/home).

## Skills:

During this summer research project, you're going to develop the ability of doing research, which includes investigating where the cutting-edge of a certain research field is by reading journal literature, using programming to reproduce some reseults, and developing your own idea to explore new directions, and so on. Other soft skills are also useful, like discussing with people, using git to organize your programming codes and using other softwares to organize the journal literature, using latex to write scienctific reports or even papers, and so on. 

Hope you'll enjoy!!

## Some useful resources:

 - A survey for literature: https://iphysresearch.github.io/Survey4GWML/
